from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Boolean, Float, Int

Pyprophet_Peptide_V0_1_0 = CommandToolBuilder(tool="pyprophet_peptide", base_command=["pyprophet", "peptide"], inputs=[ToolInput(tag="in_in", input_type=File(optional=True), prefix="--in", doc=InputDocumentation(doc="PyProphet input file.  [required]")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="--out", doc=InputDocumentation(doc="PyProphet output file.")), ToolInput(tag="in_context", input_type=Boolean(optional=True), prefix="--context", doc=InputDocumentation(doc="[run-specific|experiment-wide|global]\nContext to estimate protein-level FDR\ncontrol.  [default: run-specific]")), ToolInput(tag="in_no_parametric", input_type=Boolean(optional=True), prefix="--no-parametric", doc=InputDocumentation(doc="Do parametric estimation of p-values.\n[default: False]")), ToolInput(tag="in_no_pf_dr", input_type=Boolean(optional=True), prefix="--no-pfdr", doc=InputDocumentation(doc="Compute positive false discovery rate (pFDR)\ninstead of FDR.  [default: False]")), ToolInput(tag="in_pi_zero_lambda", input_type=Float(optional=True), prefix="--pi0_lambda", doc=InputDocumentation(doc="...\nUse non-parametric estimation of p-values.\nEither use <START END STEPS>, e.g. 0.1, 1.0,\n0.1 or set to fixed value, e.g. 0.4, 0, 0.\n[default: 0.1, 0.5, 0.05]")), ToolInput(tag="in_pi_zero_method", input_type=Boolean(optional=True), prefix="--pi0_method", doc=InputDocumentation(doc="[smoother|bootstrap]\nEither 'smoother' or 'bootstrap'; the method\nfor automatically choosing tuning parameter\nin the estimation of pi_0, the proportion of\ntrue null hypotheses.  [default: bootstrap]")), ToolInput(tag="in_pi_zero_smooth_df", input_type=Int(optional=True), prefix="--pi0_smooth_df", doc=InputDocumentation(doc="Number of degrees-of-freedom to use when\nestimating pi_0 with a smoother.  [default:\n3]")), ToolInput(tag="in_no_pi_zero_smooth_log_pi_zero", input_type=Boolean(optional=True), prefix="--no-pi0_smooth_log_pi0", doc=InputDocumentation(doc="If True and pi0_method = 'smoother', pi0\nwill be estimated by applying a smoother to\na scatterplot of log(pi0) estimates against\nthe tuning parameter lambda.  [default:\nFalse]")), ToolInput(tag="in_no_lf_dr_truncate", input_type=Boolean(optional=True), prefix="--no-lfdr_truncate", doc=InputDocumentation(doc="If True, local FDR values >1 are set to 1.\n[default: True]")), ToolInput(tag="in_no_lf_dr_monotone", input_type=Boolean(optional=True), prefix="--no-lfdr_monotone", doc=InputDocumentation(doc="If True, local FDR values are non-decreasing\nwith increasing p-values.  [default: True]")), ToolInput(tag="in_lf_dr_transformation", input_type=Boolean(optional=True), prefix="--lfdr_transformation", doc=InputDocumentation(doc="[probit|logit]\nEither a 'probit' or 'logit' transformation\nis applied to the p-values so that a local\nFDR estimate can be formed that does not\ninvolve edge effects of the [0,1] interval\nin which the p-values lie.  [default:\nprobit]")), ToolInput(tag="in_lf_dr_adj", input_type=Float(optional=True), prefix="--lfdr_adj", doc=InputDocumentation(doc="Numeric value that is applied as a multiple\nof the smoothing bandwidth used in the\ndensity estimation.  [default: 1.5]")), ToolInput(tag="in_lf_dr_eps", input_type=Float(optional=True), prefix="--lfdr_eps", doc=InputDocumentation(doc="Numeric value that is threshold for the\ntails of the empirical p-value distribution.\n[default: 1e-08]"))], outputs=[ToolOutput(tag="out_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out", type_hint=File()), doc=OutputDocumentation(doc="PyProphet output file."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Pyprophet_Peptide_V0_1_0().translate("wdl", allow_empty_container=True)

